==> aksharamukha-1.0.12.tar.gz: aksharamukha-1.0.12/aksharamukha/ScriptMap/EastIndic/LaoPali.py <==
# -*- coding: utf-8 -*-

# Script Mapping for Devanagari

VowelMap =  [
            '\u0EAD',
            '\u0EAD\u0EB2',
            '\u0EAD\u0EB4',
            '\u0EAD\u0EB5',
            '\u0EAD\u0EB8',
            '\u0EAD\u0EB9',
            '\u0EA3\u0EB8\u02BD',
            '\u0EA3\u0EB9\u02BD',
            '\u0EA5\u0EB8\u02BD',
            '\u0EA5\u0EB9\u02BD',
            '\u0EC0\u0EAD',
            '\u0EC4\u0EAD',
            '\u0EC2\u0EAD',
            '\u0EC0\u0EAD\u0EBB\u0EB2',
            ]

SouthVowelMap = [
                '\u0EC0\u0EAD\u0EB0',
                '\u0EC2\u0EAD\u0EB0',
                ]

ModernVowelMap = [
                 '\u0EC1\u0EAD\u0EB0',
                 '\u0EC0\u0EAD\u0EB2\u0EB0',
                 ]

SinhalaVowelMap = [
                  '\u0EC1\u0EAD'
                  ]

VowelSignMap =  [
                 '\u0EB2',
                 '\u0EB4',
                 '\u0EB5',
                 '\u0EB8',
                 '\u0EB9',
                 '\u0EBA\u0EA3\u0EB8\u02BD',
                 '\u0EBA\u0EA3\u0EB9\u02BD',
                 '\u0EBA\u0EA5\u0EB8\u02BD',
                 '\u0EBA\u0EA5\u0EB9\u02BD',
                 '\u0EC0',
                 '\u0EC4',
                 '\u0EC2',
                 '\u0EC0\u0EBB\u0EB2',
                ]

SouthVowelSignMap = [
                     '\u0EC0\u0EB0',
                     '\u0EC2\u0EB0',
                    ]

ModernVowelSignMap =[
                     '\u0EC1\u0EB0',
                     '\u0EC0\u0EB2\u0EB0',
                    ]

SinhalaVowelSignMap = [
                       '\u0EC1'
                      ]

AyogavahaMap = [
               '\u0ECD\u02BD',
               '\u0ECD',
               '\u0EAB\u0ECC'
               ]

ViramaMap =  [
             '\u0EBA'
             ]

ConsonantMap =  [
                '\u0E81',
                '\u0E82',
                '\u0E84',
                '\u0E86',
                '\u0E87',

                '\u0E88',
                '\u0E89',
                '\u0E8A',
                '\u0E8C',
                '\u0E8E',

                '\u0E8F',
                '\u0E90',
                '\u0E91',
                '\u0E92',
                '\u0E93',

                '\u0E95',
                '\u0E96',
                '\u0E97',
                '\u0E98',
                '\u0E99',

                '\u0E9B',
                '\u0E9C',
                '\u0E9E',
                '\u0EA0',
                '\u0EA1',

                '\u0E8D',
                '\u0EA3',
                '\u0EA5',
                '\u0EA7',

                '\u0EA8',
                '\u0EA9',
                '\u0EAA',
                '\u0EAB'
                ]

SouthConsonantMap = [
                    '\u0EAC',
                    '\u0EAC\u02BD',
                    'ຮ',
                    '\u0E99\u02BD'
                    ]

NuktaConsonantMap =  [
                    '\u0E81\u02BD',
                    '\u0E82\u02BD',
                    '\u0E84\u02BD',
                    '\u0E8A\u02BD',
                    '\u0E90\u02BD',
                    '\u0E91\u02BD',
                    'ຝ',
                    '\u0EA2',
                     ]

SinhalaConsonantMap =[
                     '\u0ECD\u0E84\u02BD',
                     '\u0ECD\u0E8A\u02BD',
                     '\u0ECD\u0E90\u02BD',
                     '\u0ECD\u0E97\u02BD',
                     '\u0ECD\u0E9E\u02BD',
                      ]

NuktaMap = [
           '\u02BD'
           ]

OmMap = [
        '\u0EC2\u0EAD\u0ECD\u02BD'
        ]

SignMap =[
         "'",
         '\u0EAF',
         '\u0EAF\u0EAF'
         ]

Aytham =[AyogavahaMap[2]+'\u02BD']

NumeralMap = [
             '\u0ED0',
             '\u0ED1',
             '\u0ED2',
             '\u0ED3',
             '\u0ED4',
             '\u0ED5',
             '\u0ED6',
             '\u0ED7',
             '\u0ED8',
             '\u0ED9'
             ]

==> aksharamukha-1.7.1.tar.gz: aksharamukha-1.7.1/aksharamukha/ScriptMap/EastIndic/LaoPali.py <==
# -*- coding: utf-8 -*-

# Script Mapping for Devanagari

VowelMap =  [
            '\u0EAD',
            '\u0EAD\u0EB2',
            '\u0EAD\u0EB4',
            '\u0EAD\u0EB5',
            '\u0EAD\u0EB8',
            '\u0EAD\u0EB9',
            '\u0EA3\u0EB8\u02BD',
            '\u0EA3\u0EB9\u02BD',
            '\u0EA5\u0EB8\u02BD',
            '\u0EA5\u0EB9\u02BD',
            '\u0EAD\u0EC0',
            '\u0EAD\u0EC4',
            '\u0EAD\u0EC2',
            '\u0EAD\u0EC0\u0EBB\u0EB2',
            ]

SouthVowelMap = [
                '\u0EAD\u0EC0\u0EB0',
                '\u0EAD\u0EC2\u0EB0',
                ]

ModernVowelMap = [
                 '\u0EAD\u0EC1\u0EB0',
                 '\u0EAD\u0EC0\u0EB2\u0EB0',
                 ]

SinhalaVowelMap = [
                  '\u0EAD\u0EC1'
                  ]

VowelSignMap =  [
                 '\u0EB2',
                 '\u0EB4',
                 '\u0EB5',
                 '\u0EB8',
                 '\u0EB9',
                 '\u0EBA\u0EA3\u0EB8\u02BD',
                 '\u0EBA\u0EA3\u0EB9\u02BD',
                 '\u0EBA\u0EA5\u0EB8\u02BD',
                 '\u0EBA\u0EA5\u0EB9\u02BD',
                 '\u0EC0',
                 '\u0EC4',
                 '\u0EC2',
                 '\u0EC0\u0EBB\u0EB2',
                ]

SouthVowelSignMap = [
                     '\u0EC0\u0EB0',
                     '\u0EC2\u0EB0',
                    ]

ModernVowelSignMap =[
                     '\u0EC1\u0EB0',
                     '\u0EC0\u0EB2\u0EB0',
                    ]

SinhalaVowelSignMap = [
                       '\u0EC1'
                      ]

AyogavahaMap = [
               '\u0ECD\u02BD',
               '\u0ECD',
               '\u0EAB\u0ECC'
               ]

ViramaMap =  [
             '\u0EBA'
             ]

ConsonantMap =  [
                '\u0E81',
                '\u0E82',
                '\u0E84',
                '\u0E86',
                '\u0E87',

                '\u0E88',
                '\u0E89',
                '\u0E8A',
                '\u0E8C',
                '\u0E8E',

                '\u0E8F',
                '\u0E90',
                '\u0E91',
                '\u0E92',
                '\u0E93',

                '\u0E95',
                '\u0E96',
                '\u0E97',
                '\u0E98',
                '\u0E99',

                '\u0E9B',
                '\u0E9C',
                '\u0E9E',
                '\u0EA0',
                '\u0EA1',

                '\u0E8D',
                '\u0EA3',
                '\u0EA5',
                '\u0EA7',

                '\u0EA8',
                '\u0EA9',
                '\u0EAA',
                '\u0EAB'
                ]

SouthConsonantMap = [
                    '\u0EAC',
                    '\u0EAC\u02BD',
                    'ຮ',
                    '\u0E99\u02BD'
                    ]

NuktaConsonantMap =  [
                    '\u0E81\u02BD',
                    '\u0E82\u02BD',
                    '\u0E84\u02BD',
                    '\u0E8A\u02BD',
                    '\u0E90\u02BD',
                    '\u0E91\u02BD',
                    'ຝ',
                    '\u0EA2',
                     ]

SinhalaConsonantMap =[
                     '\u0ECD\u0E84\u02BD',
                     '\u0ECD\u0E8A\u02BD',
                     '\u0ECD\u0E90\u02BD',
                     '\u0ECD\u0E97\u02BD',
                     '\u0ECD\u0E9E\u02BD',
                      ]

NuktaMap = [
           '\u02BD'
           ]

OmMap = [
        '\u0EC2\u0EAD\u0ECD\u02BD'
        ]

SignMap =[
         "'",
         '\u0EAF',
         '\u0EAF\u0EAF'
         ]

Aytham =[AyogavahaMap[2]+'\u02BD']

NumeralMap = [
             '\u0ED0',
             '\u0ED1',
             '\u0ED2',
             '\u0ED3',
             '\u0ED4',
             '\u0ED5',
             '\u0ED6',
             '\u0ED7',
             '\u0ED8',
             '\u0ED9'
             ]
